#! /bin/sh
# Copyright (c) 2001 SuSE GmbH Nuernberg, Germany.  All rights reserved.
#               2002-2003 SuSE Linux AG, Nuernberg, Germany
#

# check if we are started as root
# only one of UID and USER must be set correctly
if test "$UID" != 0 -a "$USER" != root; then
    echo "You must be root to start $0."
    exit 1
fi

PREFIX="/opt/mozilla/lib"
MOZ_APP="mozilla"

get_arch ()
{
  file "$1" | sed -n 's/.*: ELF [^,]*, \([^,]*\),.*/\1/p'
}

mozilla_arch=`get_arch $PREFIX/$MOZ_APP-bin`
mozilla_lib=`file $PREFIX/$MOZ_APP-bin | awk '{ print $3 }'`

GCC3=1
JAVA_CHECK_PATH="/usr/lib /usr/java"
JAVA_ORDER="mozilla ns7 ns610 [Ss]un IBM BEA"
case $mozilla_lib in
  64-bit)
        LIB=lib64
        ;;
  *)
        LIB=lib
        ;;
esac
BROWSER_PLUGIN_DIR=/usr/$LIB/browser-plugins
if [ ! -d $BROWSER_PLUGIN_DIR ]; then
  BROWSER_PLUGIN_DIR=/opt/netscape/plugins
fi

find_java ()
{
  TMP=$(find $JAVA_CHECK_PATH -name "$1" -type f)
  for i in $TMP; do
    if [ "`get_arch $i`" = "$mozilla_arch" ]; then
      PLUGIN="$PLUGIN $i"
    fi
  done
  TMP=""
}

# JAVA
if [ ! -L $PREFIX/plugins/libjavaplugin_oji.so ] ||
   [ ! -f $PREFIX/plugins/libjavaplugin_oji.so ] ; then # link is here and valid
  PLUGIN=""
  find_java *javaplugin_oji.so
  [ $GCC3 -eq 1 ] && find_java *javaplugin_ojigcc3.so # IBMJava
  if [ "$PLUGIN" ]; then
    if [ $GCC3 -eq 1 ]; then # search gcc3 plugin 
      for i in $PLUGIN; do
        if [[ $i == *mozilla* ]] || [[ $i == *gcc3* ]] || [[ $i == *ns7/* ]]; then
          TMP=$i
          break
        fi
      done
    else
      for i in $JAVA_ORDER; do
        for j in $PLUGIN; do
          if [[ "$j" == "*$i*" ]]; then
            TMP=$j
            break 2
          fi
        done
      done
    fi
  fi
  if [ "$TMP" ]; then
    PLUGIN=$TMP
    ln -sf $PLUGIN $PREFIX/plugins/libjavaplugin_oji.so
    echo "-> added Java2 plugin ($PLUGIN)"
  else
    echo "-> Java2: no change (no suitable JRE available)"
  fi
else
  echo "-> Java2: no change (existing link is valid)"
fi

# RealPlayer
if [ -f /usr/lib/RealPlayer*/rpnp.so ] && [ ! -f $PREFIX/plugins/rpnp.so ] &&
   [ "`get_arch /usr/lib/RealPlayer*/rpnp.so`" = "$mozilla_arch" ]; then
   ln -sf /usr/lib/RealPlayer*/rpnp.so $PREFIX/plugins/rpnp.so
   ln -sf /usr/lib/RealPlayer*/raclass.zip $PREFIX/plugins/raclass.zip
   echo "-> added RealPlayer plugin"
elif [ -f $BROWSER_PLUGIN_DIR/rpnp.so ] && [ ! -f $PREFIX/plugins/rpnp.so ] &&
   [ "`get_arch $BROWSER_PLUGIN_DIR/rpnp.so`" = "$mozilla_arch" ]; then
   ln -sf $BROWSER_PLUGIN_DIR/rpnp.so $PREFIX/plugins/rpnp.so
   ln -sf $BROWSER_PLUGIN_DIR/raclass.zip $PREFIX/plugins/raclass.zip
   echo "-> added RealPlayer plugin"
elif [ -f $BROWSER_PLUGIN_DIR/nphelix.so ] && [ ! -f $PREFIX/plugins/nphelix.so ] &&
   [ "`get_arch $BROWSER_PLUGIN_DIR/nphelix.so`" = "$mozilla_arch" ]; then
    ln -sf $BROWSER_PLUGIN_DIR/nphelix.so $PREFIX/plugins/nphelix.so
    ln -sf $BROWSER_PLUGIN_DIR/nphelix.xpt $PREFIX/plugins/nphelix.xpt
    echo "-> added RealPlayer/Helix plugin"
else
   echo "-> RealPlayer: no change (link valid or not available)"
fi

# Adobe Reader 7
plugin="/usr/X11R6/lib/Acrobat7/Browser/intellinux/nppdf.so"
if [ ! -f $PREFIX/plugins/nppdf.so ] &&
   [ -r $plugin ] && 
   [ "`get_arch $plugin`" = "$mozilla_arch" ]; then
   ln -sf $plugin $PREFIX/plugins/nppdf.so
   echo "-> added AdobeReader 7 plugin"
else
   echo "-> AdobeReader: no change (link valid or not available)"
fi

# Flash player (v5 <= SL8.1)
if [ -f /opt/netscape/plugins/libflashplayer.so -a \
     -f /opt/netscape/plugins/ShockwaveFlash.class ] &&
   [ ! -f $PREFIX/plugins/libflashplayer.so ] &&
   [ "`get_arch /opt/netscape/plugins/libflashplayer.so`" = "$mozilla_arch" ]; then
   ln -sf /opt/netscape/plugins/libflashplayer.so \
          $PREFIX/plugins/libflashplayer.so
   echo "-> added Flash player 5 plugin"
else
   echo "-> Flash5: no change (link valid or not available)"
fi

# Flash player (v6/7 >= SL8.2)
if [ -f $BROWSER_PLUGIN_DIR/libflashplayer.so -a \
     -f $BROWSER_PLUGIN_DIR/flashplayer.xpt ] &&
   [ ! -f $PREFIX/plugins/libflashplayer.so -o ! -f $PREFIX/plugins/flashplayer.xpt ] &&
   [ "`get_arch $BROWSER_PLUGIN_DIR/libflashplayer.so`" = "$mozilla_arch" ]; then
   ln -sf $BROWSER_PLUGIN_DIR/libflashplayer.so \
          $PREFIX/plugins/libflashplayer.so
   ln -sf $BROWSER_PLUGIN_DIR/flashplayer.xpt \
          $PREFIX/plugins/flashplayer.xpt
   echo "-> added Flash player 6/7 plugin"
else
   echo "-> Flash6/7: no change (link valid or not available)"
fi

# GPL Flash
if [ -f $BROWSER_PLUGIN_DIR/libnpflash.so ] &&
   [ ! -f $PREFIX/plugins/libflashplayer.so ] &&
   [ ! -f $PREFIX/plugins/libnpflash.so ] &&
   [ "`get_arch $BROWSER_PLUGIN_DIR/libnpflash.so`" = "$mozilla_arch" ]; then
   ln -sf $BROWSER_PLUGIN_DIR/libnpflash.so \
          $PREFIX/plugins/libnpflash.so
   echo "-> added GPL Flash player"
else
   echo "-> gplflash: no change (flash already provided or not available)"
fi

# Plugger
if [ -f $BROWSER_PLUGIN_DIR/plugger.so ] &&
   [ ! -f $PREFIX/plugins/plugger.so ] &&
   [ "`get_arch $BROWSER_PLUGIN_DIR/plugger.so`" = "$mozilla_arch" ]; then
   ln -sf $BROWSER_PLUGIN_DIR/plugger.so \
          $PREFIX/plugins/plugger.so
   echo "-> added Plugger plugin"
else
   echo "-> Plugger: no change (link valid or not available)"
fi

# mozplugger
if [ -f $BROWSER_PLUGIN_DIR/mozplugger.so ] &&
   [ ! -f $PREFIX/plugins/mozplugger.so ] &&
   [ "`get_arch $BROWSER_PLUGIN_DIR/mozplugger.so`" = "$mozilla_arch" ]; then
   ln -sf $BROWSER_PLUGIN_DIR/mozplugger.so \
          $PREFIX/plugins/mozplugger.so
   echo "-> added mozplugger plugin"
else
   echo "-> Mozplugger: no change (link valid or not available)"
fi

# Tclplug
if [ -f $BROWSER_PLUGIN_DIR/libnptcl3.0.so ] &&
   [ ! -f $PREFIX/plugins/libnptcl3.0.so ] &&
   [ "`get_arch $BROWSER_PLUGIN_DIR/libnptcl3.0.so`" = "$mozilla_arch" ]; then
   ln -sf $BROWSER_PLUGIN_DIR/libnptcl3.0.so \
          $PREFIX/plugins/libnptcl3.0.so
   echo "-> added Tcl plugin"
else
   echo "-> Tcl: no change (link valid or not available)"
fi

# DjVu
if [ -f $BROWSER_PLUGIN_DIR/nsdejavu.so ] &&
   [ ! -f $PREFIX/plugins/nsdejavu.so ] &&
   [ "`get_arch $BROWSER_PLUGIN_DIR/nsdejavu.so`" = "$mozilla_arch" ]; then
   ln -sf $BROWSER_PLUGIN_DIR/nsdejavu.so \
          $PREFIX/plugins/nsdejavu.so
   echo "-> added DjVu plugin"
else
   echo "-> DjVu: no change (link valid or not available)"
fi

# bonobo
if [ -f $BROWSER_PLUGIN_DIR/libmozilla_bonobo.so ] &&
   [ ! -f $PREFIX/plugins/libmozilla_bonobo.so ] &&
   [ "`get_arch $BROWSER_PLUGIN_DIR/libmozilla_bonobo.so`" = "$mozilla_arch" ]; then
   ln -sf $BROWSER_PLUGIN_DIR/libmozilla_bonobo.so \
          $PREFIX/plugins/libmozilla_bonobo.so
   echo "-> added bonobo plugin"
else
   echo "-> bonobo: no change (link valid or not available)"
fi 

# MySPELL
MYSPELL=/usr/share/myspell
MOZ_SPELL=$PREFIX/components/myspell
if [ -d $MOZ_SPELL ] ; then
  if [ -d $MYSPELL ] ; then
    for dict in $MYSPELL/??[-_]??.aff ; do

      # check is it is really the file or it is a string which contain '??_??'
      if ! [ -e $dict ] ; then
        continue
      fi

      # the dict file name
      dict_file=`echo ${dict##*/}`

      # the dict file has a valid name
      lang=`echo ${dict_file:0:2}`
      country=`echo ${dict_file:3:2}`
      
      # check for .dic file
      if ! [ -r $MYSPELL/${lang}[-_]${country}.dic ] ; then
        continue
      fi

      # create links
      if [ ! -r $MOZ_SPELL/${lang}[-_]${country}.aff ] ; then
        ln -sf $MYSPELL/${lang}[-_]${country}.aff \
               $MOZ_SPELL/${lang}-${country}.aff
      fi      
      if [ ! -r $MOZ_SPELL/${lang}[-_]${country}.dic ] ; then
        ln -sf $MYSPELL/${lang}[-_]${country}.dic \
               $MOZ_SPELL/${lang}-${country}.dic
      fi      
    done
    echo "-> added myspell dictionaries"
  fi

  # remove broken links
  for dict in $MOZ_SPELL/*.{aff,dic} ; do
    if ! [ -r $dict ] ; then
      rm -f $dict
    fi
  done
fi
